# coding: utf-8

"""
    accident-manager-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_accident_management_service.configuration import Configuration


class SceneDetailInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'accident_id': 'str',
        'name': 'str',
        'scenario_id': 'str',
        'data_source': 'str',
        'operator': 'str',
        'operate_time': 'datetime',
        'remark': 'str',
        'events': 'list[EventDetailInfo]'
    }

    attribute_map = {
        'id': 'id',
        'accident_id': 'accidentId',
        'name': 'name',
        'scenario_id': 'scenarioId',
        'data_source': 'dataSource',
        'operator': 'operator',
        'operate_time': 'operateTime',
        'remark': 'remark',
        'events': 'events'
    }

    def __init__(self, id=None, accident_id=None, name=None, scenario_id=None, data_source=None, operator=None, operate_time=None, remark=None, events=None, local_vars_configuration=None):  # noqa: E501
        """SceneDetailInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._accident_id = None
        self._name = None
        self._scenario_id = None
        self._data_source = None
        self._operator = None
        self._operate_time = None
        self._remark = None
        self._events = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if accident_id is not None:
            self.accident_id = accident_id
        self.name = name
        self.scenario_id = scenario_id
        self.data_source = data_source
        self.operator = operator
        if operate_time is not None:
            self.operate_time = operate_time
        self.remark = remark
        self.events = events

    @property
    def id(self):
        """Gets the id of this SceneDetailInfo.  # noqa: E501

        情景ID scene id  # noqa: E501

        :return: The id of this SceneDetailInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SceneDetailInfo.

        情景ID scene id  # noqa: E501

        :param id: The id of this SceneDetailInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def accident_id(self):
        """Gets the accident_id of this SceneDetailInfo.  # noqa: E501

        事故ID accident id  # noqa: E501

        :return: The accident_id of this SceneDetailInfo.  # noqa: E501
        :rtype: str
        """
        return self._accident_id

    @accident_id.setter
    def accident_id(self, accident_id):
        """Sets the accident_id of this SceneDetailInfo.

        事故ID accident id  # noqa: E501

        :param accident_id: The accident_id of this SceneDetailInfo.  # noqa: E501
        :type: str
        """

        self._accident_id = accident_id

    @property
    def name(self):
        """Gets the name of this SceneDetailInfo.  # noqa: E501

        情景名称 scene name  # noqa: E501

        :return: The name of this SceneDetailInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SceneDetailInfo.

        情景名称 scene name  # noqa: E501

        :param name: The name of this SceneDetailInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def scenario_id(self):
        """Gets the scenario_id of this SceneDetailInfo.  # noqa: E501

        方案ID scenario id  # noqa: E501

        :return: The scenario_id of this SceneDetailInfo.  # noqa: E501
        :rtype: str
        """
        return self._scenario_id

    @scenario_id.setter
    def scenario_id(self, scenario_id):
        """Sets the scenario_id of this SceneDetailInfo.

        方案ID scenario id  # noqa: E501

        :param scenario_id: The scenario_id of this SceneDetailInfo.  # noqa: E501
        :type: str
        """

        self._scenario_id = scenario_id

    @property
    def data_source(self):
        """Gets the data_source of this SceneDetailInfo.  # noqa: E501

        数据源 data source  # noqa: E501

        :return: The data_source of this SceneDetailInfo.  # noqa: E501
        :rtype: str
        """
        return self._data_source

    @data_source.setter
    def data_source(self, data_source):
        """Sets the data_source of this SceneDetailInfo.

        数据源 data source  # noqa: E501

        :param data_source: The data_source of this SceneDetailInfo.  # noqa: E501
        :type: str
        """

        self._data_source = data_source

    @property
    def operator(self):
        """Gets the operator of this SceneDetailInfo.  # noqa: E501

        操作人员 operator  # noqa: E501

        :return: The operator of this SceneDetailInfo.  # noqa: E501
        :rtype: str
        """
        return self._operator

    @operator.setter
    def operator(self, operator):
        """Sets the operator of this SceneDetailInfo.

        操作人员 operator  # noqa: E501

        :param operator: The operator of this SceneDetailInfo.  # noqa: E501
        :type: str
        """

        self._operator = operator

    @property
    def operate_time(self):
        """Gets the operate_time of this SceneDetailInfo.  # noqa: E501

        操作时间 operate time  # noqa: E501

        :return: The operate_time of this SceneDetailInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._operate_time

    @operate_time.setter
    def operate_time(self, operate_time):
        """Sets the operate_time of this SceneDetailInfo.

        操作时间 operate time  # noqa: E501

        :param operate_time: The operate_time of this SceneDetailInfo.  # noqa: E501
        :type: datetime
        """

        self._operate_time = operate_time

    @property
    def remark(self):
        """Gets the remark of this SceneDetailInfo.  # noqa: E501

        备注 scene remark  # noqa: E501

        :return: The remark of this SceneDetailInfo.  # noqa: E501
        :rtype: str
        """
        return self._remark

    @remark.setter
    def remark(self, remark):
        """Sets the remark of this SceneDetailInfo.

        备注 scene remark  # noqa: E501

        :param remark: The remark of this SceneDetailInfo.  # noqa: E501
        :type: str
        """

        self._remark = remark

    @property
    def events(self):
        """Gets the events of this SceneDetailInfo.  # noqa: E501

        情景下的事件信息 subordinate events  # noqa: E501

        :return: The events of this SceneDetailInfo.  # noqa: E501
        :rtype: list[EventDetailInfo]
        """
        return self._events

    @events.setter
    def events(self, events):
        """Sets the events of this SceneDetailInfo.

        情景下的事件信息 subordinate events  # noqa: E501

        :param events: The events of this SceneDetailInfo.  # noqa: E501
        :type: list[EventDetailInfo]
        """

        self._events = events

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SceneDetailInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SceneDetailInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    IoT服务

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from dhicn_iot_service.api_client import ApiClient
from dhicn_iot_service.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class DeviceApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def api_v1_iot_add_device_post(self, **kwargs):  # noqa: E501
        """增加一个设备 Add a device  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_add_device_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddDeviceInput add_device_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_iot_add_device_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_iot_add_device_post_with_http_info(self, **kwargs):  # noqa: E501
        """增加一个设备 Add a device  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_add_device_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddDeviceInput add_device_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(str, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'add_device_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_iot_add_device_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_device_input' in local_var_params:
            body_params = local_var_params['add_device_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/iot/add-device', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_iot_batch_add_device_post(self, **kwargs):  # noqa: E501
        """批量添加设备 Batch add devices  # noqa: E501

        批量添加设备，如果设备已存在，则会更新 Batch add devices, if some devices are already existed, they will be updated  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_batch_add_device_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[AddDeviceInput] add_device_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: dict(str, str)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_iot_batch_add_device_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_iot_batch_add_device_post_with_http_info(self, **kwargs):  # noqa: E501
        """批量添加设备 Batch add devices  # noqa: E501

        批量添加设备，如果设备已存在，则会更新 Batch add devices, if some devices are already existed, they will be updated  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_batch_add_device_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[AddDeviceInput] add_device_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(dict(str, str), status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'add_device_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_iot_batch_add_device_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_device_input' in local_var_params:
            body_params = local_var_params['add_device_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/iot/batch-add-device', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, str)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_iot_batch_save_device_attribute_values_post(self, **kwargs):  # noqa: E501
        """批量添加或更新设备的属性值 Add or modify device customized attributes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_batch_save_device_attribute_values_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[SaveDeviceAttributeValuesInput] save_device_attribute_values_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_iot_batch_save_device_attribute_values_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_iot_batch_save_device_attribute_values_post_with_http_info(self, **kwargs):  # noqa: E501
        """批量添加或更新设备的属性值 Add or modify device customized attributes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_batch_save_device_attribute_values_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[SaveDeviceAttributeValuesInput] save_device_attribute_values_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'save_device_attribute_values_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_iot_batch_save_device_attribute_values_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'save_device_attribute_values_input' in local_var_params:
            body_params = local_var_params['save_device_attribute_values_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/iot/batch-save-device-attribute-values', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_iot_delete_devices_post(self, **kwargs):  # noqa: E501
        """根据设备ID列表删除设备 Delete devices by ids  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_delete_devices_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param DeleteDevicesInput delete_devices_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_iot_delete_devices_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_iot_delete_devices_post_with_http_info(self, **kwargs):  # noqa: E501
        """根据设备ID列表删除设备 Delete devices by ids  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_delete_devices_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param DeleteDevicesInput delete_devices_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'delete_devices_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_iot_delete_devices_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'delete_devices_input' in local_var_params:
            body_params = local_var_params['delete_devices_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/iot/delete-devices', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_iot_device_batch_details_post(self, **kwargs):  # noqa: E501
        """根据设备IDs批量查询设备详情 Get device details in batches by device IDs  # noqa: E501

        根据设备IDs批量查询设备详情，包括设备的属性 Get detailed information of a device including attributes by device ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_device_batch_details_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param QueryDeviceDetailInput query_device_detail_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[DeviceInfosOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_iot_device_batch_details_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_iot_device_batch_details_post_with_http_info(self, **kwargs):  # noqa: E501
        """根据设备IDs批量查询设备详情 Get device details in batches by device IDs  # noqa: E501

        根据设备IDs批量查询设备详情，包括设备的属性 Get detailed information of a device including attributes by device ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_device_batch_details_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param QueryDeviceDetailInput query_device_detail_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[DeviceInfosOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'query_device_detail_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_iot_device_batch_details_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'query_device_detail_input' in local_var_params:
            body_params = local_var_params['query_device_detail_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/iot/device-batch-details', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[DeviceInfosOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_iot_device_details_get(self, **kwargs):  # noqa: E501
        """根据设备ID查询设备详情 Get device details by device ID  # noqa: E501

        根据设备ID查询设备详情，包括设备的属性 Get detailed information of a device including attributes by device ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_device_details_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: 设备ID device id
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DeviceInfosOutput
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_iot_device_details_get_with_http_info(**kwargs)  # noqa: E501

    def api_v1_iot_device_details_get_with_http_info(self, **kwargs):  # noqa: E501
        """根据设备ID查询设备详情 Get device details by device ID  # noqa: E501

        根据设备ID查询设备详情，包括设备的属性 Get detailed information of a device including attributes by device ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_device_details_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: 设备ID device id
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DeviceInfosOutput, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_iot_device_details_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'id' in local_var_params and local_var_params['id'] is not None:  # noqa: E501
            query_params.append(('id', local_var_params['id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/iot/device-details', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeviceInfosOutput',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_iot_device_keys_get(self, device_ids, **kwargs):  # noqa: E501
        """根据设备ID查询设备指标信息 Get device indicators by device ids  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_device_keys_get(device_ids, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] device_ids: 设备Id列表 device ids (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[DeviceKeysOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_iot_device_keys_get_with_http_info(device_ids, **kwargs)  # noqa: E501

    def api_v1_iot_device_keys_get_with_http_info(self, device_ids, **kwargs):  # noqa: E501
        """根据设备ID查询设备指标信息 Get device indicators by device ids  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_device_keys_get_with_http_info(device_ids, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] device_ids: 设备Id列表 device ids (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[DeviceKeysOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'device_ids'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_iot_device_keys_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'device_ids' is set
        if self.api_client.client_side_validation and ('device_ids' not in local_var_params or  # noqa: E501
                                                        local_var_params['device_ids'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `device_ids` when calling `api_v1_iot_device_keys_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'device_ids' in local_var_params and local_var_params['device_ids'] is not None:  # noqa: E501
            query_params.append(('DeviceIds', local_var_params['device_ids']))  # noqa: E501
            collection_formats['DeviceIds'] = 'multi'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/iot/device-Keys', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[DeviceKeysOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_iot_device_list_attr_post(self, **kwargs):  # noqa: E501
        """按设备属性查询设备  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_device_list_attr_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param DeviceInfosInputWithAttr device_infos_input_with_attr:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DeviceInfosOutputPage
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_iot_device_list_attr_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_iot_device_list_attr_post_with_http_info(self, **kwargs):  # noqa: E501
        """按设备属性查询设备  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_device_list_attr_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param DeviceInfosInputWithAttr device_infos_input_with_attr:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DeviceInfosOutputPage, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'device_infos_input_with_attr'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_iot_device_list_attr_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'device_infos_input_with_attr' in local_var_params:
            body_params = local_var_params['device_infos_input_with_attr']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/iot/device-list/attr', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeviceInfosOutputPage',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_iot_device_list_get(self, **kwargs):  # noqa: E501
        """分页查询设备列表 Get device list: pagination query of devices  # noqa: E501

        分页获取设备列表，结果可以基于某个属性进行排序，也可以基于某个关键词进行过滤 Get device list with pagination, results can be sorted by a certain property and keywords can be used to filter the results.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_device_list_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int sort_property: 用于排序的属性 sort attribute:  0-createdTime,  1-label,  2-name,
        :param int sort_order: 排序的方式 sort order:  0-ASC,  1-DESC
        :param str type: 设备类型
        :param int page_index:
        :param int page_size:
        :param str key_words:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DeviceInfosOutputPage
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_iot_device_list_get_with_http_info(**kwargs)  # noqa: E501

    def api_v1_iot_device_list_get_with_http_info(self, **kwargs):  # noqa: E501
        """分页查询设备列表 Get device list: pagination query of devices  # noqa: E501

        分页获取设备列表，结果可以基于某个属性进行排序，也可以基于某个关键词进行过滤 Get device list with pagination, results can be sorted by a certain property and keywords can be used to filter the results.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_device_list_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int sort_property: 用于排序的属性 sort attribute:  0-createdTime,  1-label,  2-name,
        :param int sort_order: 排序的方式 sort order:  0-ASC,  1-DESC
        :param str type: 设备类型
        :param int page_index:
        :param int page_size:
        :param str key_words:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DeviceInfosOutputPage, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'sort_property',
            'sort_order',
            'type',
            'page_index',
            'page_size',
            'key_words'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_iot_device_list_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'sort_property' in local_var_params and local_var_params['sort_property'] is not None:  # noqa: E501
            query_params.append(('SortProperty', local_var_params['sort_property']))  # noqa: E501
        if 'sort_order' in local_var_params and local_var_params['sort_order'] is not None:  # noqa: E501
            query_params.append(('SortOrder', local_var_params['sort_order']))  # noqa: E501
        if 'type' in local_var_params and local_var_params['type'] is not None:  # noqa: E501
            query_params.append(('Type', local_var_params['type']))  # noqa: E501
        if 'page_index' in local_var_params and local_var_params['page_index'] is not None:  # noqa: E501
            query_params.append(('PageIndex', local_var_params['page_index']))  # noqa: E501
        if 'page_size' in local_var_params and local_var_params['page_size'] is not None:  # noqa: E501
            query_params.append(('PageSize', local_var_params['page_size']))  # noqa: E501
        if 'key_words' in local_var_params and local_var_params['key_words'] is not None:  # noqa: E501
            query_params.append(('KeyWords', local_var_params['key_words']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/iot/device-list', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeviceInfosOutputPage',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_iot_device_list_without_indicator_get(self, **kwargs):  # noqa: E501
        """分页查询设备列表 Get device list: pagination query of devices  # noqa: E501

        分页获取设备列表，结果可以基于某个属性进行排序，也可以基于某个关键词进行过滤 Get device list with pagination, results can be sorted by a certain property and keywords can be used to filter the results.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_device_list_without_indicator_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int sort_property: 用于排序的属性 sort attribute:  0-createdTime,  1-label,  2-name,
        :param int sort_order: 排序的方式 sort order:  0-ASC,  1-DESC
        :param str type: 设备类型
        :param int page_index:
        :param int page_size:
        :param str key_words:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DeviceInfosOutputPage
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_iot_device_list_without_indicator_get_with_http_info(**kwargs)  # noqa: E501

    def api_v1_iot_device_list_without_indicator_get_with_http_info(self, **kwargs):  # noqa: E501
        """分页查询设备列表 Get device list: pagination query of devices  # noqa: E501

        分页获取设备列表，结果可以基于某个属性进行排序，也可以基于某个关键词进行过滤 Get device list with pagination, results can be sorted by a certain property and keywords can be used to filter the results.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_device_list_without_indicator_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int sort_property: 用于排序的属性 sort attribute:  0-createdTime,  1-label,  2-name,
        :param int sort_order: 排序的方式 sort order:  0-ASC,  1-DESC
        :param str type: 设备类型
        :param int page_index:
        :param int page_size:
        :param str key_words:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DeviceInfosOutputPage, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'sort_property',
            'sort_order',
            'type',
            'page_index',
            'page_size',
            'key_words'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_iot_device_list_without_indicator_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'sort_property' in local_var_params and local_var_params['sort_property'] is not None:  # noqa: E501
            query_params.append(('SortProperty', local_var_params['sort_property']))  # noqa: E501
        if 'sort_order' in local_var_params and local_var_params['sort_order'] is not None:  # noqa: E501
            query_params.append(('SortOrder', local_var_params['sort_order']))  # noqa: E501
        if 'type' in local_var_params and local_var_params['type'] is not None:  # noqa: E501
            query_params.append(('Type', local_var_params['type']))  # noqa: E501
        if 'page_index' in local_var_params and local_var_params['page_index'] is not None:  # noqa: E501
            query_params.append(('PageIndex', local_var_params['page_index']))  # noqa: E501
        if 'page_size' in local_var_params and local_var_params['page_size'] is not None:  # noqa: E501
            query_params.append(('PageSize', local_var_params['page_size']))  # noqa: E501
        if 'key_words' in local_var_params and local_var_params['key_words'] is not None:  # noqa: E501
            query_params.append(('KeyWords', local_var_params['key_words']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/iot/device-list-withoutIndicator', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeviceInfosOutputPage',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_iot_query_device_attributes_post(self, **kwargs):  # noqa: E501
        """查询设备的属性 Get device attributes  # noqa: E501

        通过属性的键查询设备属性值，如果传入的属性键为空，则返回所有的属性值 Get device attributes through attribute keys, if attribute keys is empty, it will return all the attributes  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_query_device_attributes_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param GetAttributesInput get_attributes_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[StringStringKeyValue]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_iot_query_device_attributes_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_iot_query_device_attributes_post_with_http_info(self, **kwargs):  # noqa: E501
        """查询设备的属性 Get device attributes  # noqa: E501

        通过属性的键查询设备属性值，如果传入的属性键为空，则返回所有的属性值 Get device attributes through attribute keys, if attribute keys is empty, it will return all the attributes  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_query_device_attributes_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param GetAttributesInput get_attributes_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[StringStringKeyValue], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'get_attributes_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_iot_query_device_attributes_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'get_attributes_input' in local_var_params:
            body_params = local_var_params['get_attributes_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/iot/query-device-attributes', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[StringStringKeyValue]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_iot_save_device_attribute_values_post(self, **kwargs):  # noqa: E501
        """添加或更新设备的属性值 Add or modify device customized attributes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_save_device_attribute_values_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param SaveDeviceAttributeValuesInput save_device_attribute_values_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_iot_save_device_attribute_values_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_iot_save_device_attribute_values_post_with_http_info(self, **kwargs):  # noqa: E501
        """添加或更新设备的属性值 Add or modify device customized attributes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_save_device_attribute_values_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param SaveDeviceAttributeValuesInput save_device_attribute_values_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'save_device_attribute_values_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_iot_save_device_attribute_values_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'save_device_attribute_values_input' in local_var_params:
            body_params = local_var_params['save_device_attribute_values_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/iot/save-device-attribute-values', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_iot_update_device_post(self, **kwargs):  # noqa: E501
        """更新一个设备 Update a device  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_update_device_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateDeviceInput update_device_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_iot_update_device_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_iot_update_device_post_with_http_info(self, **kwargs):  # noqa: E501
        """更新一个设备 Update a device  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_update_device_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateDeviceInput update_device_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(str, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'update_device_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_iot_update_device_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_device_input' in local_var_params:
            body_params = local_var_params['update_device_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/iot/update-device', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v2_iot_device_batch_details_post(self, **kwargs):  # noqa: E501
        """根据设备IDs批量查询设备详情(多线程) Get device details in batches by device IDs  # noqa: E501

        根据设备IDs批量查询设备详情，包括设备的属性 Get detailed information of a device including attributes by device ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_iot_device_batch_details_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param QueryDeviceDetailInput query_device_detail_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[DeviceInfosOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v2_iot_device_batch_details_post_with_http_info(**kwargs)  # noqa: E501

    def api_v2_iot_device_batch_details_post_with_http_info(self, **kwargs):  # noqa: E501
        """根据设备IDs批量查询设备详情(多线程) Get device details in batches by device IDs  # noqa: E501

        根据设备IDs批量查询设备详情，包括设备的属性 Get detailed information of a device including attributes by device ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_iot_device_batch_details_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param QueryDeviceDetailInput query_device_detail_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[DeviceInfosOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'query_device_detail_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v2_iot_device_batch_details_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'query_device_detail_input' in local_var_params:
            body_params = local_var_params['query_device_detail_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/iot/device-batch-details', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[DeviceInfosOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    model-information-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_model_information_service.configuration import Configuration


class QueryTankDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'device_id': 'str',
        'muid': 'str',
        'elev': 'float',
        'hgl': 'float',
        'zone_id': 'str',
        'data_source': 'str',
        'description': 'str',
        'wd_tank_hgl_type': 'int',
        'pattern_id': 'str',
        'wd_tank_mixing': 'int',
        'init_quality_concentration': 'float',
        'reaction_coefficient': 'float',
        'init_quality_percentage': 'float',
        'ini_quality_hour': 'float',
        'component_value': 'float',
        'coor_str': 'str',
        'create_time': 'datetime',
        'id': 'str'
    }

    attribute_map = {
        'device_id': 'deviceId',
        'muid': 'muid',
        'elev': 'elev',
        'hgl': 'hgl',
        'zone_id': 'zoneID',
        'data_source': 'dataSource',
        'description': 'description',
        'wd_tank_hgl_type': 'wdTankHGLType',
        'pattern_id': 'patternID',
        'wd_tank_mixing': 'wdTankMixing',
        'init_quality_concentration': 'initQualityConcentration',
        'reaction_coefficient': 'reactionCoefficient',
        'init_quality_percentage': 'initQualityPercentage',
        'ini_quality_hour': 'iniQualityHour',
        'component_value': 'componentValue',
        'coor_str': 'coorStr',
        'create_time': 'createTime',
        'id': 'id'
    }

    def __init__(self, device_id=None, muid=None, elev=None, hgl=None, zone_id=None, data_source=None, description=None, wd_tank_hgl_type=None, pattern_id=None, wd_tank_mixing=None, init_quality_concentration=None, reaction_coefficient=None, init_quality_percentage=None, ini_quality_hour=None, component_value=None, coor_str=None, create_time=None, id=None, local_vars_configuration=None):  # noqa: E501
        """QueryTankDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._device_id = None
        self._muid = None
        self._elev = None
        self._hgl = None
        self._zone_id = None
        self._data_source = None
        self._description = None
        self._wd_tank_hgl_type = None
        self._pattern_id = None
        self._wd_tank_mixing = None
        self._init_quality_concentration = None
        self._reaction_coefficient = None
        self._init_quality_percentage = None
        self._ini_quality_hour = None
        self._component_value = None
        self._coor_str = None
        self._create_time = None
        self._id = None
        self.discriminator = None

        if device_id is not None:
            self.device_id = device_id
        self.muid = muid
        if elev is not None:
            self.elev = elev
        if hgl is not None:
            self.hgl = hgl
        self.zone_id = zone_id
        self.data_source = data_source
        self.description = description
        if wd_tank_hgl_type is not None:
            self.wd_tank_hgl_type = wd_tank_hgl_type
        self.pattern_id = pattern_id
        if wd_tank_mixing is not None:
            self.wd_tank_mixing = wd_tank_mixing
        if init_quality_concentration is not None:
            self.init_quality_concentration = init_quality_concentration
        if reaction_coefficient is not None:
            self.reaction_coefficient = reaction_coefficient
        if init_quality_percentage is not None:
            self.init_quality_percentage = init_quality_percentage
        if ini_quality_hour is not None:
            self.ini_quality_hour = ini_quality_hour
        if component_value is not None:
            self.component_value = component_value
        self.coor_str = coor_str
        if create_time is not None:
            self.create_time = create_time
        if id is not None:
            self.id = id

    @property
    def device_id(self):
        """Gets the device_id of this QueryTankDto.  # noqa: E501

        设备ID device id  # noqa: E501

        :return: The device_id of this QueryTankDto.  # noqa: E501
        :rtype: str
        """
        return self._device_id

    @device_id.setter
    def device_id(self, device_id):
        """Sets the device_id of this QueryTankDto.

        设备ID device id  # noqa: E501

        :param device_id: The device_id of this QueryTankDto.  # noqa: E501
        :type: str
        """

        self._device_id = device_id

    @property
    def muid(self):
        """Gets the muid of this QueryTankDto.  # noqa: E501

        模型中水池ID tank muid  # noqa: E501

        :return: The muid of this QueryTankDto.  # noqa: E501
        :rtype: str
        """
        return self._muid

    @muid.setter
    def muid(self, muid):
        """Sets the muid of this QueryTankDto.

        模型中水池ID tank muid  # noqa: E501

        :param muid: The muid of this QueryTankDto.  # noqa: E501
        :type: str
        """

        self._muid = muid

    @property
    def elev(self):
        """Gets the elev of this QueryTankDto.  # noqa: E501

        底高程 base elevation  # noqa: E501

        :return: The elev of this QueryTankDto.  # noqa: E501
        :rtype: float
        """
        return self._elev

    @elev.setter
    def elev(self, elev):
        """Sets the elev of this QueryTankDto.

        底高程 base elevation  # noqa: E501

        :param elev: The elev of this QueryTankDto.  # noqa: E501
        :type: float
        """

        self._elev = elev

    @property
    def hgl(self):
        """Gets the hgl of this QueryTankDto.  # noqa: E501

        水头固定值 fixed HGL  # noqa: E501

        :return: The hgl of this QueryTankDto.  # noqa: E501
        :rtype: float
        """
        return self._hgl

    @hgl.setter
    def hgl(self, hgl):
        """Sets the hgl of this QueryTankDto.

        水头固定值 fixed HGL  # noqa: E501

        :param hgl: The hgl of this QueryTankDto.  # noqa: E501
        :type: float
        """

        self._hgl = hgl

    @property
    def zone_id(self):
        """Gets the zone_id of this QueryTankDto.  # noqa: E501

        分区ID zone id  # noqa: E501

        :return: The zone_id of this QueryTankDto.  # noqa: E501
        :rtype: str
        """
        return self._zone_id

    @zone_id.setter
    def zone_id(self, zone_id):
        """Sets the zone_id of this QueryTankDto.

        分区ID zone id  # noqa: E501

        :param zone_id: The zone_id of this QueryTankDto.  # noqa: E501
        :type: str
        """

        self._zone_id = zone_id

    @property
    def data_source(self):
        """Gets the data_source of this QueryTankDto.  # noqa: E501

        数据源 data source  # noqa: E501

        :return: The data_source of this QueryTankDto.  # noqa: E501
        :rtype: str
        """
        return self._data_source

    @data_source.setter
    def data_source(self, data_source):
        """Sets the data_source of this QueryTankDto.

        数据源 data source  # noqa: E501

        :param data_source: The data_source of this QueryTankDto.  # noqa: E501
        :type: str
        """

        self._data_source = data_source

    @property
    def description(self):
        """Gets the description of this QueryTankDto.  # noqa: E501

        描述 description  # noqa: E501

        :return: The description of this QueryTankDto.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this QueryTankDto.

        描述 description  # noqa: E501

        :param description: The description of this QueryTankDto.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def wd_tank_hgl_type(self):
        """Gets the wd_tank_hgl_type of this QueryTankDto.  # noqa: E501

        水池水头类型 HGL level type  # noqa: E501

        :return: The wd_tank_hgl_type of this QueryTankDto.  # noqa: E501
        :rtype: int
        """
        return self._wd_tank_hgl_type

    @wd_tank_hgl_type.setter
    def wd_tank_hgl_type(self, wd_tank_hgl_type):
        """Sets the wd_tank_hgl_type of this QueryTankDto.

        水池水头类型 HGL level type  # noqa: E501

        :param wd_tank_hgl_type: The wd_tank_hgl_type of this QueryTankDto.  # noqa: E501
        :type: int
        """

        self._wd_tank_hgl_type = wd_tank_hgl_type

    @property
    def pattern_id(self):
        """Gets the pattern_id of this QueryTankDto.  # noqa: E501

        水头模式ID HGL pattern id  # noqa: E501

        :return: The pattern_id of this QueryTankDto.  # noqa: E501
        :rtype: str
        """
        return self._pattern_id

    @pattern_id.setter
    def pattern_id(self, pattern_id):
        """Sets the pattern_id of this QueryTankDto.

        水头模式ID HGL pattern id  # noqa: E501

        :param pattern_id: The pattern_id of this QueryTankDto.  # noqa: E501
        :type: str
        """

        self._pattern_id = pattern_id

    @property
    def wd_tank_mixing(self):
        """Gets the wd_tank_mixing of this QueryTankDto.  # noqa: E501

        水池混合的类型 tank mixing type  # noqa: E501

        :return: The wd_tank_mixing of this QueryTankDto.  # noqa: E501
        :rtype: int
        """
        return self._wd_tank_mixing

    @wd_tank_mixing.setter
    def wd_tank_mixing(self, wd_tank_mixing):
        """Sets the wd_tank_mixing of this QueryTankDto.

        水池混合的类型 tank mixing type  # noqa: E501

        :param wd_tank_mixing: The wd_tank_mixing of this QueryTankDto.  # noqa: E501
        :type: int
        """

        self._wd_tank_mixing = wd_tank_mixing

    @property
    def init_quality_concentration(self):
        """Gets the init_quality_concentration of this QueryTankDto.  # noqa: E501

        初始污染物浓度 initial chemical concentration  # noqa: E501

        :return: The init_quality_concentration of this QueryTankDto.  # noqa: E501
        :rtype: float
        """
        return self._init_quality_concentration

    @init_quality_concentration.setter
    def init_quality_concentration(self, init_quality_concentration):
        """Sets the init_quality_concentration of this QueryTankDto.

        初始污染物浓度 initial chemical concentration  # noqa: E501

        :param init_quality_concentration: The init_quality_concentration of this QueryTankDto.  # noqa: E501
        :type: float
        """

        self._init_quality_concentration = init_quality_concentration

    @property
    def reaction_coefficient(self):
        """Gets the reaction_coefficient of this QueryTankDto.  # noqa: E501

        降解系数 reaction coefficient  # noqa: E501

        :return: The reaction_coefficient of this QueryTankDto.  # noqa: E501
        :rtype: float
        """
        return self._reaction_coefficient

    @reaction_coefficient.setter
    def reaction_coefficient(self, reaction_coefficient):
        """Sets the reaction_coefficient of this QueryTankDto.

        降解系数 reaction coefficient  # noqa: E501

        :param reaction_coefficient: The reaction_coefficient of this QueryTankDto.  # noqa: E501
        :type: float
        """

        self._reaction_coefficient = reaction_coefficient

    @property
    def init_quality_percentage(self):
        """Gets the init_quality_percentage of this QueryTankDto.  # noqa: E501

        初始污染物占比 initial source percentage  # noqa: E501

        :return: The init_quality_percentage of this QueryTankDto.  # noqa: E501
        :rtype: float
        """
        return self._init_quality_percentage

    @init_quality_percentage.setter
    def init_quality_percentage(self, init_quality_percentage):
        """Sets the init_quality_percentage of this QueryTankDto.

        初始污染物占比 initial source percentage  # noqa: E501

        :param init_quality_percentage: The init_quality_percentage of this QueryTankDto.  # noqa: E501
        :type: float
        """

        self._init_quality_percentage = init_quality_percentage

    @property
    def ini_quality_hour(self):
        """Gets the ini_quality_hour of this QueryTankDto.  # noqa: E501

        初始水龄 initial water age  # noqa: E501

        :return: The ini_quality_hour of this QueryTankDto.  # noqa: E501
        :rtype: float
        """
        return self._ini_quality_hour

    @ini_quality_hour.setter
    def ini_quality_hour(self, ini_quality_hour):
        """Sets the ini_quality_hour of this QueryTankDto.

        初始水龄 initial water age  # noqa: E501

        :param ini_quality_hour: The ini_quality_hour of this QueryTankDto.  # noqa: E501
        :type: float
        """

        self._ini_quality_hour = ini_quality_hour

    @property
    def component_value(self):
        """Gets the component_value of this QueryTankDto.  # noqa: E501

        污染物体积 component volume  # noqa: E501

        :return: The component_value of this QueryTankDto.  # noqa: E501
        :rtype: float
        """
        return self._component_value

    @component_value.setter
    def component_value(self, component_value):
        """Sets the component_value of this QueryTankDto.

        污染物体积 component volume  # noqa: E501

        :param component_value: The component_value of this QueryTankDto.  # noqa: E501
        :type: float
        """

        self._component_value = component_value

    @property
    def coor_str(self):
        """Gets the coor_str of this QueryTankDto.  # noqa: E501

        坐标值 coordinate  # noqa: E501

        :return: The coor_str of this QueryTankDto.  # noqa: E501
        :rtype: str
        """
        return self._coor_str

    @coor_str.setter
    def coor_str(self, coor_str):
        """Sets the coor_str of this QueryTankDto.

        坐标值 coordinate  # noqa: E501

        :param coor_str: The coor_str of this QueryTankDto.  # noqa: E501
        :type: str
        """

        self._coor_str = coor_str

    @property
    def create_time(self):
        """Gets the create_time of this QueryTankDto.  # noqa: E501

        创建时间 create time  # noqa: E501

        :return: The create_time of this QueryTankDto.  # noqa: E501
        :rtype: datetime
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """Sets the create_time of this QueryTankDto.

        创建时间 create time  # noqa: E501

        :param create_time: The create_time of this QueryTankDto.  # noqa: E501
        :type: datetime
        """

        self._create_time = create_time

    @property
    def id(self):
        """Gets the id of this QueryTankDto.  # noqa: E501

        水池ID tank id  # noqa: E501

        :return: The id of this QueryTankDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this QueryTankDto.

        水池ID tank id  # noqa: E501

        :param id: The id of this QueryTankDto.  # noqa: E501
        :type: str
        """

        self._id = id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, QueryTankDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, QueryTankDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    model-information-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_model_information_service.configuration import Configuration


class AddJunctionDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'muid': 'str',
        'node_type': 'int',
        'elevation': 'float',
        'surface_elevation': 'float',
        'zone_id': 'str',
        'init_chemical_concentration': 'float',
        'init_source_percentage': 'float',
        'init_water_age': 'float',
        'description': 'str',
        'data_source': 'str',
        'asset_name': 'str',
        'x': 'float',
        'y': 'float',
        'operate': 'OperateEnum'
    }

    attribute_map = {
        'muid': 'muid',
        'node_type': 'nodeType',
        'elevation': 'elevation',
        'surface_elevation': 'surfaceElevation',
        'zone_id': 'zoneID',
        'init_chemical_concentration': 'initChemicalConcentration',
        'init_source_percentage': 'initSourcePercentage',
        'init_water_age': 'initWaterAge',
        'description': 'description',
        'data_source': 'dataSource',
        'asset_name': 'assetName',
        'x': 'x',
        'y': 'y',
        'operate': 'operate'
    }

    def __init__(self, muid=None, node_type=None, elevation=None, surface_elevation=None, zone_id=None, init_chemical_concentration=None, init_source_percentage=None, init_water_age=None, description=None, data_source=None, asset_name=None, x=None, y=None, operate=None, local_vars_configuration=None):  # noqa: E501
        """AddJunctionDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._muid = None
        self._node_type = None
        self._elevation = None
        self._surface_elevation = None
        self._zone_id = None
        self._init_chemical_concentration = None
        self._init_source_percentage = None
        self._init_water_age = None
        self._description = None
        self._data_source = None
        self._asset_name = None
        self._x = None
        self._y = None
        self._operate = None
        self.discriminator = None

        self.muid = muid
        if node_type is not None:
            self.node_type = node_type
        if elevation is not None:
            self.elevation = elevation
        if surface_elevation is not None:
            self.surface_elevation = surface_elevation
        self.zone_id = zone_id
        if init_chemical_concentration is not None:
            self.init_chemical_concentration = init_chemical_concentration
        if init_source_percentage is not None:
            self.init_source_percentage = init_source_percentage
        if init_water_age is not None:
            self.init_water_age = init_water_age
        self.description = description
        self.data_source = data_source
        self.asset_name = asset_name
        if x is not None:
            self.x = x
        if y is not None:
            self.y = y
        if operate is not None:
            self.operate = operate

    @property
    def muid(self):
        """Gets the muid of this AddJunctionDto.  # noqa: E501

        模型中节点ID junction muid  # noqa: E501

        :return: The muid of this AddJunctionDto.  # noqa: E501
        :rtype: str
        """
        return self._muid

    @muid.setter
    def muid(self, muid):
        """Sets the muid of this AddJunctionDto.

        模型中节点ID junction muid  # noqa: E501

        :param muid: The muid of this AddJunctionDto.  # noqa: E501
        :type: str
        """

        self._muid = muid

    @property
    def node_type(self):
        """Gets the node_type of this AddJunctionDto.  # noqa: E501

        节点类型 node type  # noqa: E501

        :return: The node_type of this AddJunctionDto.  # noqa: E501
        :rtype: int
        """
        return self._node_type

    @node_type.setter
    def node_type(self, node_type):
        """Sets the node_type of this AddJunctionDto.

        节点类型 node type  # noqa: E501

        :param node_type: The node_type of this AddJunctionDto.  # noqa: E501
        :type: int
        """

        self._node_type = node_type

    @property
    def elevation(self):
        """Gets the elevation of this AddJunctionDto.  # noqa: E501

        高程 elevation  # noqa: E501

        :return: The elevation of this AddJunctionDto.  # noqa: E501
        :rtype: float
        """
        return self._elevation

    @elevation.setter
    def elevation(self, elevation):
        """Sets the elevation of this AddJunctionDto.

        高程 elevation  # noqa: E501

        :param elevation: The elevation of this AddJunctionDto.  # noqa: E501
        :type: float
        """

        self._elevation = elevation

    @property
    def surface_elevation(self):
        """Gets the surface_elevation of this AddJunctionDto.  # noqa: E501

        表面高程 surface elevation  # noqa: E501

        :return: The surface_elevation of this AddJunctionDto.  # noqa: E501
        :rtype: float
        """
        return self._surface_elevation

    @surface_elevation.setter
    def surface_elevation(self, surface_elevation):
        """Sets the surface_elevation of this AddJunctionDto.

        表面高程 surface elevation  # noqa: E501

        :param surface_elevation: The surface_elevation of this AddJunctionDto.  # noqa: E501
        :type: float
        """

        self._surface_elevation = surface_elevation

    @property
    def zone_id(self):
        """Gets the zone_id of this AddJunctionDto.  # noqa: E501

        分区ID zone id  # noqa: E501

        :return: The zone_id of this AddJunctionDto.  # noqa: E501
        :rtype: str
        """
        return self._zone_id

    @zone_id.setter
    def zone_id(self, zone_id):
        """Sets the zone_id of this AddJunctionDto.

        分区ID zone id  # noqa: E501

        :param zone_id: The zone_id of this AddJunctionDto.  # noqa: E501
        :type: str
        """

        self._zone_id = zone_id

    @property
    def init_chemical_concentration(self):
        """Gets the init_chemical_concentration of this AddJunctionDto.  # noqa: E501

        初始化学物质浓度 initial chemical concentration  # noqa: E501

        :return: The init_chemical_concentration of this AddJunctionDto.  # noqa: E501
        :rtype: float
        """
        return self._init_chemical_concentration

    @init_chemical_concentration.setter
    def init_chemical_concentration(self, init_chemical_concentration):
        """Sets the init_chemical_concentration of this AddJunctionDto.

        初始化学物质浓度 initial chemical concentration  # noqa: E501

        :param init_chemical_concentration: The init_chemical_concentration of this AddJunctionDto.  # noqa: E501
        :type: float
        """

        self._init_chemical_concentration = init_chemical_concentration

    @property
    def init_source_percentage(self):
        """Gets the init_source_percentage of this AddJunctionDto.  # noqa: E501

        初始水量占比 initial source percentage  # noqa: E501

        :return: The init_source_percentage of this AddJunctionDto.  # noqa: E501
        :rtype: float
        """
        return self._init_source_percentage

    @init_source_percentage.setter
    def init_source_percentage(self, init_source_percentage):
        """Sets the init_source_percentage of this AddJunctionDto.

        初始水量占比 initial source percentage  # noqa: E501

        :param init_source_percentage: The init_source_percentage of this AddJunctionDto.  # noqa: E501
        :type: float
        """

        self._init_source_percentage = init_source_percentage

    @property
    def init_water_age(self):
        """Gets the init_water_age of this AddJunctionDto.  # noqa: E501

        初始水龄 initial water age  # noqa: E501

        :return: The init_water_age of this AddJunctionDto.  # noqa: E501
        :rtype: float
        """
        return self._init_water_age

    @init_water_age.setter
    def init_water_age(self, init_water_age):
        """Sets the init_water_age of this AddJunctionDto.

        初始水龄 initial water age  # noqa: E501

        :param init_water_age: The init_water_age of this AddJunctionDto.  # noqa: E501
        :type: float
        """

        self._init_water_age = init_water_age

    @property
    def description(self):
        """Gets the description of this AddJunctionDto.  # noqa: E501

        描述 description  # noqa: E501

        :return: The description of this AddJunctionDto.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this AddJunctionDto.

        描述 description  # noqa: E501

        :param description: The description of this AddJunctionDto.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def data_source(self):
        """Gets the data_source of this AddJunctionDto.  # noqa: E501

        数据源 data source  # noqa: E501

        :return: The data_source of this AddJunctionDto.  # noqa: E501
        :rtype: str
        """
        return self._data_source

    @data_source.setter
    def data_source(self, data_source):
        """Sets the data_source of this AddJunctionDto.

        数据源 data source  # noqa: E501

        :param data_source: The data_source of this AddJunctionDto.  # noqa: E501
        :type: str
        """

        self._data_source = data_source

    @property
    def asset_name(self):
        """Gets the asset_name of this AddJunctionDto.  # noqa: E501

        资产名称 asset name  # noqa: E501

        :return: The asset_name of this AddJunctionDto.  # noqa: E501
        :rtype: str
        """
        return self._asset_name

    @asset_name.setter
    def asset_name(self, asset_name):
        """Sets the asset_name of this AddJunctionDto.

        资产名称 asset name  # noqa: E501

        :param asset_name: The asset_name of this AddJunctionDto.  # noqa: E501
        :type: str
        """

        self._asset_name = asset_name

    @property
    def x(self):
        """Gets the x of this AddJunctionDto.  # noqa: E501

        节点坐标X coordinate x  # noqa: E501

        :return: The x of this AddJunctionDto.  # noqa: E501
        :rtype: float
        """
        return self._x

    @x.setter
    def x(self, x):
        """Sets the x of this AddJunctionDto.

        节点坐标X coordinate x  # noqa: E501

        :param x: The x of this AddJunctionDto.  # noqa: E501
        :type: float
        """

        self._x = x

    @property
    def y(self):
        """Gets the y of this AddJunctionDto.  # noqa: E501

        节点坐标Y coordinate y  # noqa: E501

        :return: The y of this AddJunctionDto.  # noqa: E501
        :rtype: float
        """
        return self._y

    @y.setter
    def y(self, y):
        """Sets the y of this AddJunctionDto.

        节点坐标Y coordinate y  # noqa: E501

        :param y: The y of this AddJunctionDto.  # noqa: E501
        :type: float
        """

        self._y = y

    @property
    def operate(self):
        """Gets the operate of this AddJunctionDto.  # noqa: E501


        :return: The operate of this AddJunctionDto.  # noqa: E501
        :rtype: OperateEnum
        """
        return self._operate

    @operate.setter
    def operate(self, operate):
        """Sets the operate of this AddJunctionDto.


        :param operate: The operate of this AddJunctionDto.  # noqa: E501
        :type: OperateEnum
        """

        self._operate = operate

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddJunctionDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AddJunctionDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    identity-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_identity_service.configuration import Configuration


class UpdateRolePermissionsInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'tenant_id': 'str',
        'roles': 'list[str]',
        'regular': 'str',
        'is_carry_auth': 'bool',
        'service_key': 'str',
        'priority': 'int',
        'id': 'str'
    }

    attribute_map = {
        'tenant_id': 'tenantId',
        'roles': 'roles',
        'regular': 'regular',
        'is_carry_auth': 'isCarryAuth',
        'service_key': 'serviceKey',
        'priority': 'priority',
        'id': 'id'
    }

    def __init__(self, tenant_id=None, roles=None, regular=None, is_carry_auth=None, service_key=None, priority=None, id=None, local_vars_configuration=None):  # noqa: E501
        """UpdateRolePermissionsInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._tenant_id = None
        self._roles = None
        self._regular = None
        self._is_carry_auth = None
        self._service_key = None
        self._priority = None
        self._id = None
        self.discriminator = None

        self.tenant_id = tenant_id
        self.roles = roles
        self.regular = regular
        self.is_carry_auth = is_carry_auth
        self.service_key = service_key
        if priority is not None:
            self.priority = priority
        if id is not None:
            self.id = id

    @property
    def tenant_id(self):
        """Gets the tenant_id of this UpdateRolePermissionsInput.  # noqa: E501

        租户Id tenant id  # noqa: E501

        :return: The tenant_id of this UpdateRolePermissionsInput.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this UpdateRolePermissionsInput.

        租户Id tenant id  # noqa: E501

        :param tenant_id: The tenant_id of this UpdateRolePermissionsInput.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    @property
    def roles(self):
        """Gets the roles of this UpdateRolePermissionsInput.  # noqa: E501

        角色:admin,oper roles  # noqa: E501

        :return: The roles of this UpdateRolePermissionsInput.  # noqa: E501
        :rtype: list[str]
        """
        return self._roles

    @roles.setter
    def roles(self, roles):
        """Sets the roles of this UpdateRolePermissionsInput.

        角色:admin,oper roles  # noqa: E501

        :param roles: The roles of this UpdateRolePermissionsInput.  # noqa: E501
        :type: list[str]
        """

        self._roles = roles

    @property
    def regular(self):
        """Gets the regular of this UpdateRolePermissionsInput.  # noqa: E501

        角色下的权限规则 role permission regular  # noqa: E501

        :return: The regular of this UpdateRolePermissionsInput.  # noqa: E501
        :rtype: str
        """
        return self._regular

    @regular.setter
    def regular(self, regular):
        """Sets the regular of this UpdateRolePermissionsInput.

        角色下的权限规则 role permission regular  # noqa: E501

        :param regular: The regular of this UpdateRolePermissionsInput.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and regular is None:  # noqa: E501
            raise ValueError("Invalid value for `regular`, must not be `None`")  # noqa: E501

        self._regular = regular

    @property
    def is_carry_auth(self):
        """Gets the is_carry_auth of this UpdateRolePermissionsInput.  # noqa: E501

        是否携带Auth if carry authentication  # noqa: E501

        :return: The is_carry_auth of this UpdateRolePermissionsInput.  # noqa: E501
        :rtype: bool
        """
        return self._is_carry_auth

    @is_carry_auth.setter
    def is_carry_auth(self, is_carry_auth):
        """Sets the is_carry_auth of this UpdateRolePermissionsInput.

        是否携带Auth if carry authentication  # noqa: E501

        :param is_carry_auth: The is_carry_auth of this UpdateRolePermissionsInput.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and is_carry_auth is None:  # noqa: E501
            raise ValueError("Invalid value for `is_carry_auth`, must not be `None`")  # noqa: E501

        self._is_carry_auth = is_carry_auth

    @property
    def service_key(self):
        """Gets the service_key of this UpdateRolePermissionsInput.  # noqa: E501

        微服务标识 micro service key  # noqa: E501

        :return: The service_key of this UpdateRolePermissionsInput.  # noqa: E501
        :rtype: str
        """
        return self._service_key

    @service_key.setter
    def service_key(self, service_key):
        """Sets the service_key of this UpdateRolePermissionsInput.

        微服务标识 micro service key  # noqa: E501

        :param service_key: The service_key of this UpdateRolePermissionsInput.  # noqa: E501
        :type: str
        """

        self._service_key = service_key

    @property
    def priority(self):
        """Gets the priority of this UpdateRolePermissionsInput.  # noqa: E501

        优先级 priority  # noqa: E501

        :return: The priority of this UpdateRolePermissionsInput.  # noqa: E501
        :rtype: int
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """Sets the priority of this UpdateRolePermissionsInput.

        优先级 priority  # noqa: E501

        :param priority: The priority of this UpdateRolePermissionsInput.  # noqa: E501
        :type: int
        """

        self._priority = priority

    @property
    def id(self):
        """Gets the id of this UpdateRolePermissionsInput.  # noqa: E501

        角色权限ID role permission id  # noqa: E501

        :return: The id of this UpdateRolePermissionsInput.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this UpdateRolePermissionsInput.

        角色权限ID role permission id  # noqa: E501

        :param id: The id of this UpdateRolePermissionsInput.  # noqa: E501
        :type: str
        """

        self._id = id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateRolePermissionsInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateRolePermissionsInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    scenario-compute-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_scenario_compute_service.configuration import Configuration


class DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'scenario_id': 'str',
        'tenant_id': 'str',
        'trigger_type': 'int',
        'execute_cycle': 'float',
        'trigger_threshold': 'str',
        'trigger_cancel_threshold': 'str',
        'continues_cycle': 'float',
        'previous_hours': 'float',
        'forecast_hours': 'float',
        'business_type': 'int',
        'library_type': 'int'
    }

    attribute_map = {
        'id': 'id',
        'scenario_id': 'scenarioId',
        'tenant_id': 'tenantId',
        'trigger_type': 'triggerType',
        'execute_cycle': 'executeCycle',
        'trigger_threshold': 'triggerThreshold',
        'trigger_cancel_threshold': 'triggerCancelThreshold',
        'continues_cycle': 'continuesCycle',
        'previous_hours': 'previousHours',
        'forecast_hours': 'forecastHours',
        'business_type': 'businessType',
        'library_type': 'libraryType'
    }

    def __init__(self, id=None, scenario_id=None, tenant_id=None, trigger_type=None, execute_cycle=None, trigger_threshold=None, trigger_cancel_threshold=None, continues_cycle=None, previous_hours=None, forecast_hours=None, business_type=None, library_type=None, local_vars_configuration=None):  # noqa: E501
        """DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._scenario_id = None
        self._tenant_id = None
        self._trigger_type = None
        self._execute_cycle = None
        self._trigger_threshold = None
        self._trigger_cancel_threshold = None
        self._continues_cycle = None
        self._previous_hours = None
        self._forecast_hours = None
        self._business_type = None
        self._library_type = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.scenario_id = scenario_id
        self.tenant_id = tenant_id
        if trigger_type is not None:
            self.trigger_type = trigger_type
        if execute_cycle is not None:
            self.execute_cycle = execute_cycle
        self.trigger_threshold = trigger_threshold
        self.trigger_cancel_threshold = trigger_cancel_threshold
        if continues_cycle is not None:
            self.continues_cycle = continues_cycle
        if previous_hours is not None:
            self.previous_hours = previous_hours
        if forecast_hours is not None:
            self.forecast_hours = forecast_hours
        if business_type is not None:
            self.business_type = business_type
        if library_type is not None:
            self.library_type = library_type

    @property
    def id(self):
        """Gets the id of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.  # noqa: E501

        Data id  # noqa: E501

        :return: The id of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.

        Data id  # noqa: E501

        :param id: The id of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def scenario_id(self):
        """Gets the scenario_id of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.  # noqa: E501

        Scenario id  # noqa: E501

        :return: The scenario_id of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.  # noqa: E501
        :rtype: str
        """
        return self._scenario_id

    @scenario_id.setter
    def scenario_id(self, scenario_id):
        """Sets the scenario_id of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.

        Scenario id  # noqa: E501

        :param scenario_id: The scenario_id of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.  # noqa: E501
        :type: str
        """

        self._scenario_id = scenario_id

    @property
    def tenant_id(self):
        """Gets the tenant_id of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.  # noqa: E501

        Tenant id  # noqa: E501

        :return: The tenant_id of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.

        Tenant id  # noqa: E501

        :param tenant_id: The tenant_id of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    @property
    def trigger_type(self):
        """Gets the trigger_type of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.  # noqa: E501

        0-Cycle 1-Condition   # noqa: E501

        :return: The trigger_type of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.  # noqa: E501
        :rtype: int
        """
        return self._trigger_type

    @trigger_type.setter
    def trigger_type(self, trigger_type):
        """Sets the trigger_type of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.

        0-Cycle 1-Condition   # noqa: E501

        :param trigger_type: The trigger_type of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.  # noqa: E501
        :type: int
        """
        allowed_values = [0, 1]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and trigger_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `trigger_type` ({0}), must be one of {1}"  # noqa: E501
                .format(trigger_type, allowed_values)
            )

        self._trigger_type = trigger_type

    @property
    def execute_cycle(self):
        """Gets the execute_cycle of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.  # noqa: E501

        定时触发的周期 小时  # noqa: E501

        :return: The execute_cycle of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.  # noqa: E501
        :rtype: float
        """
        return self._execute_cycle

    @execute_cycle.setter
    def execute_cycle(self, execute_cycle):
        """Sets the execute_cycle of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.

        定时触发的周期 小时  # noqa: E501

        :param execute_cycle: The execute_cycle of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.  # noqa: E501
        :type: float
        """

        self._execute_cycle = execute_cycle

    @property
    def trigger_threshold(self):
        """Gets the trigger_threshold of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.  # noqa: E501

        Trigger autoforecast threshold  # noqa: E501

        :return: The trigger_threshold of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.  # noqa: E501
        :rtype: str
        """
        return self._trigger_threshold

    @trigger_threshold.setter
    def trigger_threshold(self, trigger_threshold):
        """Sets the trigger_threshold of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.

        Trigger autoforecast threshold  # noqa: E501

        :param trigger_threshold: The trigger_threshold of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.  # noqa: E501
        :type: str
        """

        self._trigger_threshold = trigger_threshold

    @property
    def trigger_cancel_threshold(self):
        """Gets the trigger_cancel_threshold of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.  # noqa: E501

        Trigger cancel autoforecast threshold  # noqa: E501

        :return: The trigger_cancel_threshold of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.  # noqa: E501
        :rtype: str
        """
        return self._trigger_cancel_threshold

    @trigger_cancel_threshold.setter
    def trigger_cancel_threshold(self, trigger_cancel_threshold):
        """Sets the trigger_cancel_threshold of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.

        Trigger cancel autoforecast threshold  # noqa: E501

        :param trigger_cancel_threshold: The trigger_cancel_threshold of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.  # noqa: E501
        :type: str
        """

        self._trigger_cancel_threshold = trigger_cancel_threshold

    @property
    def continues_cycle(self):
        """Gets the continues_cycle of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.  # noqa: E501

        Timed forecast cycles  # noqa: E501

        :return: The continues_cycle of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.  # noqa: E501
        :rtype: float
        """
        return self._continues_cycle

    @continues_cycle.setter
    def continues_cycle(self, continues_cycle):
        """Sets the continues_cycle of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.

        Timed forecast cycles  # noqa: E501

        :param continues_cycle: The continues_cycle of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.  # noqa: E501
        :type: float
        """

        self._continues_cycle = continues_cycle

    @property
    def previous_hours(self):
        """Gets the previous_hours of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.  # noqa: E501

        Previous hours  # noqa: E501

        :return: The previous_hours of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.  # noqa: E501
        :rtype: float
        """
        return self._previous_hours

    @previous_hours.setter
    def previous_hours(self, previous_hours):
        """Sets the previous_hours of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.

        Previous hours  # noqa: E501

        :param previous_hours: The previous_hours of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.  # noqa: E501
        :type: float
        """

        self._previous_hours = previous_hours

    @property
    def forecast_hours(self):
        """Gets the forecast_hours of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.  # noqa: E501

        Forecast hours  # noqa: E501

        :return: The forecast_hours of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.  # noqa: E501
        :rtype: float
        """
        return self._forecast_hours

    @forecast_hours.setter
    def forecast_hours(self, forecast_hours):
        """Sets the forecast_hours of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.

        Forecast hours  # noqa: E501

        :param forecast_hours: The forecast_hours of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.  # noqa: E501
        :type: float
        """

        self._forecast_hours = forecast_hours

    @property
    def business_type(self):
        """Gets the business_type of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.  # noqa: E501

        0-Undefined(Undefined) 1-WaterEnvironment(Water environment) 2-UrbanFlooding(Urban flooding) 3-UrbanWD(Water distribution) 4-RiverFlood(River flood)   # noqa: E501

        :return: The business_type of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.  # noqa: E501
        :rtype: int
        """
        return self._business_type

    @business_type.setter
    def business_type(self, business_type):
        """Sets the business_type of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.

        0-Undefined(Undefined) 1-WaterEnvironment(Water environment) 2-UrbanFlooding(Urban flooding) 3-UrbanWD(Water distribution) 4-RiverFlood(River flood)   # noqa: E501

        :param business_type: The business_type of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.  # noqa: E501
        :type: int
        """
        allowed_values = [0, 1, 2, 3, 4]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and business_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `business_type` ({0}), must be one of {1}"  # noqa: E501
                .format(business_type, allowed_values)
            )

        self._business_type = business_type

    @property
    def library_type(self):
        """Gets the library_type of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.  # noqa: E501

        0-Undefined(Undefined) 1-AutoForecast(Auto forecast library) 2-ManualForecast(Manual forecast library) 3-Forecast(Forecast library) 4-Schedule(Schedule library) 5-Experience(Experience library) 6-ScenarioSimulation(Scenario simulation library) 7-WQAccident(Water quality accident library) 8-OnlineHD(WD Hydrodynamic library) 9-WaterHammer(WD water hammer library) 10-Filling(WD pipe filling library) 11-PipeBurst(WD pipe burst library) 12-WQResponse(Water quality accident response library) 13-Planning(WD planning library) 14-Flushing(WD flushing library) 15-OnlineWQAccident(Online Water quality accident library) 16-CloseValve(WD close valve library)   # noqa: E501

        :return: The library_type of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.  # noqa: E501
        :rtype: int
        """
        return self._library_type

    @library_type.setter
    def library_type(self, library_type):
        """Sets the library_type of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.

        0-Undefined(Undefined) 1-AutoForecast(Auto forecast library) 2-ManualForecast(Manual forecast library) 3-Forecast(Forecast library) 4-Schedule(Schedule library) 5-Experience(Experience library) 6-ScenarioSimulation(Scenario simulation library) 7-WQAccident(Water quality accident library) 8-OnlineHD(WD Hydrodynamic library) 9-WaterHammer(WD water hammer library) 10-Filling(WD pipe filling library) 11-PipeBurst(WD pipe burst library) 12-WQResponse(Water quality accident response library) 13-Planning(WD planning library) 14-Flushing(WD flushing library) 15-OnlineWQAccident(Online Water quality accident library) 16-CloseValve(WD close valve library)   # noqa: E501

        :param library_type: The library_type of this DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo.  # noqa: E501
        :type: int
        """
        allowed_values = [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and library_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `library_type` ({0}), must be one of {1}"  # noqa: E501
                .format(library_type, allowed_values)
            )

        self._library_type = library_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    wd-domain-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from dhicn_wd_domain_service.api.accident_api import AccidentApi
from dhicn_wd_domain_service.api.accuracy_config_api import AccuracyConfigApi
from dhicn_wd_domain_service.api.alarm_config_api import AlarmConfigApi
from dhicn_wd_domain_service.api.alarm_log_api import AlarmLogApi
from dhicn_wd_domain_service.api.document_api import DocumentApi
from dhicn_wd_domain_service.api.gis_api import GISApi
from dhicn_wd_domain_service.api.indicator_config_api import IndicatorConfigApi
from dhicn_wd_domain_service.api.online_api import OnlineApi
from dhicn_wd_domain_service.api.pipe_risk_api import PipeRiskApi
from dhicn_wd_domain_service.api.scenario_compute_api import ScenarioComputeApi
from dhicn_wd_domain_service.api.schedule_api import ScheduleApi
from dhicn_wd_domain_service.api.statistic_api import StatisticApi
from dhicn_wd_domain_service.api.valve_config_api import ValveConfigApi

# import ApiClient
from dhicn_wd_domain_service.api_client import ApiClient
from dhicn_wd_domain_service.configuration import Configuration
from dhicn_wd_domain_service.exceptions import OpenApiException
from dhicn_wd_domain_service.exceptions import ApiTypeError
from dhicn_wd_domain_service.exceptions import ApiValueError
from dhicn_wd_domain_service.exceptions import ApiKeyError
from dhicn_wd_domain_service.exceptions import ApiException
# import models into sdk package
from dhicn_wd_domain_service.models.accuracy_config_dto import AccuracyConfigDto
from dhicn_wd_domain_service.models.add_accuracy_config_input import AddAccuracyConfigInput
from dhicn_wd_domain_service.models.add_alarm_config_input import AddAlarmConfigInput
from dhicn_wd_domain_service.models.add_broken_pipe_risk_para_cfg_input import AddBrokenPipeRiskParaCfgInput
from dhicn_wd_domain_service.models.add_list_alarm_config_input import AddListAlarmConfigInput
from dhicn_wd_domain_service.models.add_pipe_risk_property_input import AddPipeRiskPropertyInput
from dhicn_wd_domain_service.models.add_pipe_risk_weight_input import AddPipeRiskWeightInput
from dhicn_wd_domain_service.models.alarm_config_dto import AlarmConfigDto
from dhicn_wd_domain_service.models.alarm_log_dto import AlarmLogDto
from dhicn_wd_domain_service.models.burst_pipe_valves_item import BurstPipeValvesItem
from dhicn_wd_domain_service.models.close_gis_valve_info import CloseGisValveInfo
from dhicn_wd_domain_service.models.component_detail_info import ComponentDetailInfo
from dhicn_wd_domain_service.models.control_ts_info import ControlTsInfo
from dhicn_wd_domain_service.models.current_online_data import CurrentOnlineData
from dhicn_wd_domain_service.models.current_online_model_data import CurrentOnlineModelData
from dhicn_wd_domain_service.models.curve_info import CurveInfo
from dhicn_wd_domain_service.models.curve_ts_info import CurveTsInfo
from dhicn_wd_domain_service.models.delete_accuracy_config_input import DeleteAccuracyConfigInput
from dhicn_wd_domain_service.models.delete_alarm_config_input import DeleteAlarmConfigInput
from dhicn_wd_domain_service.models.device_detail_info import DeviceDetailInfo
from dhicn_wd_domain_service.models.device_indicator_info import DeviceIndicatorInfo
from dhicn_wd_domain_service.models.device_indicator_para import DeviceIndicatorPara
from dhicn_wd_domain_service.models.device_info import DeviceInfo
from dhicn_wd_domain_service.models.event_detail_info import EventDetailInfo
from dhicn_wd_domain_service.models.find_burst_pipe_valves_batch import FindBurstPipeValvesBatch
from dhicn_wd_domain_service.models.find_burst_pipe_valves_input import FindBurstPipeValvesInput
from dhicn_wd_domain_service.models.get_accuracy_para import GetAccuracyPara
from dhicn_wd_domain_service.models.get_alarm_log_by_type_input import GetAlarmLogByTypeInput
from dhicn_wd_domain_service.models.get_current_data_para import GetCurrentDataPara
from dhicn_wd_domain_service.models.get_online_model_data_para import GetOnlineModelDataPara
from dhicn_wd_domain_service.models.get_valves_by_pipe_ids_input import GetValvesByPipeIdsInput
from dhicn_wd_domain_service.models.gis_valve_info import GisValveInfo
from dhicn_wd_domain_service.models.indicator_info import IndicatorInfo
from dhicn_wd_domain_service.models.indicator_list import IndicatorList
from dhicn_wd_domain_service.models.int32_double_key_value import Int32DoubleKeyValue
from dhicn_wd_domain_service.models.int32_model_pipe_info_list_key_value import Int32ModelPipeInfoListKeyValue
from dhicn_wd_domain_service.models.model_map_assembly_info import ModelMapAssemblyInfo
from dhicn_wd_domain_service.models.model_pipe_info import ModelPipeInfo
from dhicn_wd_domain_service.models.model_point_info import ModelPointInfo
from dhicn_wd_domain_service.models.online_accuracy_data import OnlineAccuracyData
from dhicn_wd_domain_service.models.online_data import OnlineData
from dhicn_wd_domain_service.models.online_model_data import OnlineModelData
from dhicn_wd_domain_service.models.pattern_info import PatternInfo
from dhicn_wd_domain_service.models.pattern_ts_info import PatternTsInfo
from dhicn_wd_domain_service.models.pipe_risk_param_output import PipeRiskParamOutput
from dhicn_wd_domain_service.models.pipe_risk_property_output import PipeRiskPropertyOutput
from dhicn_wd_domain_service.models.pipe_risk_weight_output import PipeRiskWeightOutput
from dhicn_wd_domain_service.models.point_data_type_info import PointDataTypeInfo
from dhicn_wd_domain_service.models.pump_info import PumpInfo
from dhicn_wd_domain_service.models.remote_service_error_info import RemoteServiceErrorInfo
from dhicn_wd_domain_service.models.remote_service_error_response import RemoteServiceErrorResponse
from dhicn_wd_domain_service.models.remote_service_validation_error_info import RemoteServiceValidationErrorInfo
from dhicn_wd_domain_service.models.save_alarm_config_by_type_input import SaveAlarmConfigByTypeInput
from dhicn_wd_domain_service.models.save_close_gis_valve_input import SaveCloseGisValveInput
from dhicn_wd_domain_service.models.save_indicator_config_input import SaveIndicatorConfigInput
from dhicn_wd_domain_service.models.save_pipe_burst_info_input import SavePipeBurstInfoInput
from dhicn_wd_domain_service.models.save_wq_accident_info_input import SaveWqAccidentInfoInput
from dhicn_wd_domain_service.models.scene_detail_info import SceneDetailInfo
from dhicn_wd_domain_service.models.statistic_info import StatisticInfo
from dhicn_wd_domain_service.models.statistic_query_input import StatisticQueryInput
from dhicn_wd_domain_service.models.stream import Stream
from dhicn_wd_domain_service.models.tank_storage_data import TankStorageData
from dhicn_wd_domain_service.models.ts_pairs import TsPairs
from dhicn_wd_domain_service.models.update_control_ts_input import UpdateControlTsInput
from dhicn_wd_domain_service.models.update_curve_ts_input import UpdateCurveTsInput
from dhicn_wd_domain_service.models.update_pattern_ts_input import UpdatePatternTsInput
from dhicn_wd_domain_service.models.update_pipe_risk_param_input import UpdatePipeRiskParamInput
from dhicn_wd_domain_service.models.update_pipe_risk_property_input import UpdatePipeRiskPropertyInput
from dhicn_wd_domain_service.models.update_pipe_risk_weight_input import UpdatePipeRiskWeightInput
from dhicn_wd_domain_service.models.value_info import ValueInfo
from dhicn_wd_domain_service.models.valve_info import ValveInfo
from dhicn_wd_domain_service.models.wd_component_detail_input import WdComponentDetailInput
from dhicn_wd_domain_service.models.wd_event_detail_input import WdEventDetailInput
from dhicn_wd_domain_service.models.wd_indicator_attr import WdIndicatorAttr
from dhicn_wd_domain_service.models.wq_event_detail_input import WqEventDetailInput




# coding: utf-8

"""
    result-analysis-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_result_analysis_service.configuration import Configuration


class QueryRainOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'rain_id': 'str',
        'start_time': 'datetime',
        'end_time': 'datetime',
        'measure_rainfall': 'float',
        'forecast_rainfall': 'float',
        'status': 'RainfallStatusEnum',
        'scenarios': 'list[str]'
    }

    attribute_map = {
        'rain_id': 'rainId',
        'start_time': 'startTime',
        'end_time': 'endTime',
        'measure_rainfall': 'measureRainfall',
        'forecast_rainfall': 'forecastRainfall',
        'status': 'status',
        'scenarios': 'scenarios'
    }

    def __init__(self, rain_id=None, start_time=None, end_time=None, measure_rainfall=None, forecast_rainfall=None, status=None, scenarios=None, local_vars_configuration=None):  # noqa: E501
        """QueryRainOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._rain_id = None
        self._start_time = None
        self._end_time = None
        self._measure_rainfall = None
        self._forecast_rainfall = None
        self._status = None
        self._scenarios = None
        self.discriminator = None

        if rain_id is not None:
            self.rain_id = rain_id
        if start_time is not None:
            self.start_time = start_time
        if end_time is not None:
            self.end_time = end_time
        if measure_rainfall is not None:
            self.measure_rainfall = measure_rainfall
        if forecast_rainfall is not None:
            self.forecast_rainfall = forecast_rainfall
        if status is not None:
            self.status = status
        self.scenarios = scenarios

    @property
    def rain_id(self):
        """Gets the rain_id of this QueryRainOutput.  # noqa: E501

        降雨记录的ID rain id  # noqa: E501

        :return: The rain_id of this QueryRainOutput.  # noqa: E501
        :rtype: str
        """
        return self._rain_id

    @rain_id.setter
    def rain_id(self, rain_id):
        """Sets the rain_id of this QueryRainOutput.

        降雨记录的ID rain id  # noqa: E501

        :param rain_id: The rain_id of this QueryRainOutput.  # noqa: E501
        :type: str
        """

        self._rain_id = rain_id

    @property
    def start_time(self):
        """Gets the start_time of this QueryRainOutput.  # noqa: E501

        降雨记录的开始时间 rainfall start time  # noqa: E501

        :return: The start_time of this QueryRainOutput.  # noqa: E501
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this QueryRainOutput.

        降雨记录的开始时间 rainfall start time  # noqa: E501

        :param start_time: The start_time of this QueryRainOutput.  # noqa: E501
        :type: datetime
        """

        self._start_time = start_time

    @property
    def end_time(self):
        """Gets the end_time of this QueryRainOutput.  # noqa: E501

        降雨记录的结束时间 rainfall end time  # noqa: E501

        :return: The end_time of this QueryRainOutput.  # noqa: E501
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this QueryRainOutput.

        降雨记录的结束时间 rainfall end time  # noqa: E501

        :param end_time: The end_time of this QueryRainOutput.  # noqa: E501
        :type: datetime
        """

        self._end_time = end_time

    @property
    def measure_rainfall(self):
        """Gets the measure_rainfall of this QueryRainOutput.  # noqa: E501

        实测总降雨量 measured total rainfall  # noqa: E501

        :return: The measure_rainfall of this QueryRainOutput.  # noqa: E501
        :rtype: float
        """
        return self._measure_rainfall

    @measure_rainfall.setter
    def measure_rainfall(self, measure_rainfall):
        """Sets the measure_rainfall of this QueryRainOutput.

        实测总降雨量 measured total rainfall  # noqa: E501

        :param measure_rainfall: The measure_rainfall of this QueryRainOutput.  # noqa: E501
        :type: float
        """

        self._measure_rainfall = measure_rainfall

    @property
    def forecast_rainfall(self):
        """Gets the forecast_rainfall of this QueryRainOutput.  # noqa: E501

        预报总降雨量 forecast total rainfall  # noqa: E501

        :return: The forecast_rainfall of this QueryRainOutput.  # noqa: E501
        :rtype: float
        """
        return self._forecast_rainfall

    @forecast_rainfall.setter
    def forecast_rainfall(self, forecast_rainfall):
        """Sets the forecast_rainfall of this QueryRainOutput.

        预报总降雨量 forecast total rainfall  # noqa: E501

        :param forecast_rainfall: The forecast_rainfall of this QueryRainOutput.  # noqa: E501
        :type: float
        """

        self._forecast_rainfall = forecast_rainfall

    @property
    def status(self):
        """Gets the status of this QueryRainOutput.  # noqa: E501


        :return: The status of this QueryRainOutput.  # noqa: E501
        :rtype: RainfallStatusEnum
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this QueryRainOutput.


        :param status: The status of this QueryRainOutput.  # noqa: E501
        :type: RainfallStatusEnum
        """

        self._status = status

    @property
    def scenarios(self):
        """Gets the scenarios of this QueryRainOutput.  # noqa: E501

        与降雨记录关联的方案ID列表 scenarios associated with this rainfall  # noqa: E501

        :return: The scenarios of this QueryRainOutput.  # noqa: E501
        :rtype: list[str]
        """
        return self._scenarios

    @scenarios.setter
    def scenarios(self, scenarios):
        """Sets the scenarios of this QueryRainOutput.

        与降雨记录关联的方案ID列表 scenarios associated with this rainfall  # noqa: E501

        :param scenarios: The scenarios of this QueryRainOutput.  # noqa: E501
        :type: list[str]
        """

        self._scenarios = scenarios

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, QueryRainOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, QueryRainOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa
"""
    message-center-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from dhicn_message_service.models.add_message_type_input import AddMessageTypeInput
from dhicn_message_service.models.add_msg_type_temp_local_input import AddMsgTypeTempLocalInput
from dhicn_message_service.models.add_user_msg import AddUserMsg
from dhicn_message_service.models.count_by_level import CountByLevel
from dhicn_message_service.models.delete_client_input import DeleteClientInput
from dhicn_message_service.models.get_lastest_message_input import GetLastestMessageInput
from dhicn_message_service.models.last_msg import LastMsg
from dhicn_message_service.models.lastest_message_by_msg_type_input import LastestMessageByMsgTypeInput
from dhicn_message_service.models.message_type_output import MessageTypeOutput
from dhicn_message_service.models.message_type_output_page import MessageTypeOutputPage
from dhicn_message_service.models.msg_template_obj import MsgTemplateObj
from dhicn_message_service.models.msg_type_temp_local_output import MsgTypeTempLocalOutput
from dhicn_message_service.models.msg_type_temp_local_output_page import MsgTypeTempLocalOutputPage
from dhicn_message_service.models.remote_service_error_info import RemoteServiceErrorInfo
from dhicn_message_service.models.remote_service_error_response import RemoteServiceErrorResponse
from dhicn_message_service.models.remote_service_validation_error_info import RemoteServiceValidationErrorInfo
from dhicn_message_service.models.save_client_input import SaveClientInput
from dhicn_message_service.models.unread_count_query_input import UnreadCountQueryInput
from dhicn_message_service.models.unread_count_query_output import UnreadCountQueryOutput
from dhicn_message_service.models.update_message_type_input import UpdateMessageTypeInput
from dhicn_message_service.models.update_msg_type_temp_local_input import UpdateMsgTypeTempLocalInput
from dhicn_message_service.models.update_user_msg_status import UpdateUserMsgStatus
from dhicn_message_service.models.user_message_object import UserMessageObject
from dhicn_message_service.models.user_msg_output import UserMsgOutput
from dhicn_message_service.models.user_msg_output_page import UserMsgOutputPage
